core

package
v0.9.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 8, 2026 License: BSD-3-Clause Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var CoreFs embed.FS

Functions

func Clean

func Clean(dirtyPath string) (cleanPath string)

Clean will remove any prefix from the file path and do other path cleaning functions to improve extensibility of the embed FS

func FindEmbeddedFile

func FindEmbeddedFile(filename string) ([]string, error)

find a filename in the list of embedded file systems

func FindFile

func FindFile(fileName string) (filePaths []string, err error)

func HasFilePath

func HasFilePath(filePath string) bool

Types

This section is empty.

Jump to