Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var CoreFs embed.FS
Functions ¶
func Clean ¶
Clean will remove any prefix from the file path and do other path cleaning functions to improve extensibility of the embed FS
func FindEmbeddedFile ¶
find a filename in the list of embedded file systems
func HasFilePath ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.